/*
PPKMouseAddon
 by Mnjul/purincess (Min-Zhong Lu)
 # Middle Sea, Mnjul's Intimate Home

Copyright 2007-2010 Min-Zhong Lu

This file is part of PPKMouseAddon.

PPKMouseAddon is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

PPKMouseAddon is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
License for more details.

You should have received a copy of the GNU Lesser General Public License
along with PPKMouseAddon.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SETTINGS_H
#define __SETTINGS_H

class Settings
{
public:
	enum LRRL {LR_TO_LR, LR_TO_RL};
	enum ButtonWheelScrollKeyPair {ORIGINAL=0, PAGEUPDOWN, BRACKET, FB};

private:
	Settings():enabled(true), enabledMouseLeft(true), enabledMouseWheel(true), enabledMouseRight(true), enabledMouseMiddle(true), lrrl(LR_TO_RL), keypairLeftButtonWheelScroll(PAGEUPDOWN), keypairRightButtonWheelScroll(BRACKET){
	}
	~Settings(){
	}
	Settings(const Settings&);	//no copy constructor
	Settings& operator=(const Settings&);	// no assignment operation constructor

	bool enabled;
	bool enabledMouseLeft;
	bool enabledMouseWheel;
	bool enabledMouseRight;
	bool enabledMouseMiddle;
	LRRL lrrl;

	ButtonWheelScrollKeyPair keypairLeftButtonWheelScroll;
	ButtonWheelScrollKeyPair keypairRightButtonWheelScroll;

	struct HotKey{
		WORD vkeyCode;
		WORD modifiers;
		HotKey():vkeyCode(0), modifiers(0)
		{
		}
	};

	HotKey hkLR, hkLW, hkRL, hkRW, hkWL, hkWR;

protected:
	void loadHotKeySetting(HotKey* hotkey, const std::wstring& valueName);	
	void saveHotKeySetting(const HotKey& hotkey, const std::wstring& valueName) const;	

public:
	static Settings& getInstance(){
		static Settings instance;
		return instance;
	}

	void loadSettings();
	void saveSettings() const;

	void setEnabled(bool enabled){
		this->enabled = enabled;
	}

	bool getEnabled() const{
		return this->enabled;
	}

	bool getEnabledMouseLeft() const{
		return this->enabledMouseLeft;
	}

	bool getEnabledMouseRight() const{
		return this->enabledMouseRight;
	}

	bool getEnabledMouseMiddle() const{
		return this->enabledMouseMiddle;
	}

	bool getEnabledMouseWheel() const{
		return this->enabledMouseWheel;
	}

	const HotKey& getHKLR() const{
		return this->hkLR;
	}

	const HotKey& getHKLW() const{
		return this->hkLW;
	}

	const HotKey& getHKRL() const{
		return this->hkRL;
	}

	const HotKey& getHKRW(){
		return this->hkRW;
	}

	const HotKey& getHKWL() const{
		return this->hkWL;
	}

	const HotKey& getHKWR() const{
		return this->hkWR;
	}

	LRRL getLRRL() const{
		return this->lrrl;
	}

	ButtonWheelScrollKeyPair getKeyPairLeftButtonWheelScroll() const{
		return this->keypairLeftButtonWheelScroll;
	}

	ButtonWheelScrollKeyPair getKeyPairRightButtonWheelScroll() const{
		return this->keypairRightButtonWheelScroll;
	}

public:
	friend class OptionsDlg;
};

#endif